@@ -1,5 +1,5 @@
 #include "ecore_con_base.eo.h"
 #include "ecore_con_server.eo.h"
-#include "ecore_con_connector.eo.h"
+#include "efl_network_connector.eo.h"
 #include "ecore_con_client.eo.h"
 #include "efl_network_url.eo.h"
